@@ -32,15 +32,16 @@
  *
  * Since: 1.0
  */
-
 struct _SnapdApp
 {
     GObject parent_instance;
 
     SnapdDaemonType daemon_type;
     gchar *name;
-    gchar **aliases;
+    gchar *snap;
     gchar *desktop_file;
+    gboolean enabled;
+    gboolean active;
 };
 
 enum
@@ -49,6 +50,9 @@ enum
     PROP_ALIASES,
     PROP_DAEMON_TYPE,
     PROP_DESKTOP_FILE,
+    PROP_SNAP,
+    PROP_ACTIVE,
+    PROP_ENABLED,
     PROP_LAST
 };
 
@@ -71,6 +75,23 @@ snapd_app_get_name (SnapdApp *app)
     return app->name;
 }
 
+/**
+ * snapd_app_get_active:
+ * @app: a #SnapdApp.
+ *
+ * Get if this service is active.
+ *
+ * Returns: %TRUE if active.
+ *
+ * Since: 1.25
+ */
+gboolean
+snapd_app_get_active (SnapdApp *app)
+{
+    g_return_val_if_fail (SNAPD_IS_APP (app), FALSE);
+    return app->active;
+}
+
 /**
  * snapd_app_get_aliases:
  * @app: a #SnapdApp.
@@ -80,12 +101,13 @@ snapd_app_get_name (SnapdApp *app)
  * Returns: (transfer none) (array zero-terminated=1): the alias names.
  *
  * Since: 1.7
+ * Deprecated: 1.25
  */
 gchar **
 snapd_app_get_aliases (SnapdApp *app)
 {
     g_return_val_if_fail (SNAPD_IS_APP (app), NULL);
-    return app->aliases;
+    return NULL;
 }
 
 /**
@@ -122,6 +144,40 @@ snapd_app_get_desktop_file (SnapdApp *app)
     return app->desktop_file;
 }
 
+/**
+ * snapd_app_get_enabled:
+ * @app: a #SnapdApp.
+ *
+ * Get if this service is enabled.
+ *
+ * Returns: %TRUE if enabled.
+ *
+ * Since: 1.25
+ */
+gboolean
+snapd_app_get_enabled (SnapdApp *app)
+{
+    g_return_val_if_fail (SNAPD_IS_APP (app), FALSE);
+    return app->enabled;
+}
+
+/**
+ * snapd_app_get_snap:
+ * @app: a #SnapdApp.
+ *
+ * Get the snap this app is associated with.
+ *
+ * Returns: a snap name.
+ *
+ * Since: 1.25
+ */
+const gchar *
+snapd_app_get_snap (SnapdApp *app)
+{
+    g_return_val_if_fail (SNAPD_IS_APP (app), NULL);
+    return app->snap;
+}
+
 static void
 snapd_app_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -133,8 +189,6 @@ snapd_app_set_property (GObject *object, guint prop_id, const GValue *value, GPa
         app->name = g_strdup (g_value_get_string (value));
         break;
     case PROP_ALIASES:
-        g_strfreev (app->aliases);
-        app->aliases = g_strdupv (g_value_get_boxed (value));
         break;
     case PROP_DAEMON_TYPE:
         app->daemon_type = g_value_get_enum (value);
@@ -143,6 +197,16 @@ snapd_app_set_property (GObject *object, guint prop_id, const GValue *value, GPa
         g_free (app->desktop_file);
         app->desktop_file = g_strdup (g_value_get_string (value));
         break;
+    case PROP_SNAP:
+        g_free (app->snap);
+        app->snap = g_strdup (g_value_get_string (value));
+        break;
+    case PROP_ACTIVE:
+        app->active = g_value_get_boolean (value);
+        break;
+    case PROP_ENABLED:
+        app->enabled = g_value_get_boolean (value);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -159,7 +223,7 @@ snapd_app_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
         g_value_set_string (value, app->name);
         break;
     case PROP_ALIASES:
-        g_value_set_boxed (value, app->aliases);
+        g_value_set_boxed (value, NULL);
         break;
     case PROP_DAEMON_TYPE:
         g_value_set_enum (value, app->daemon_type);
@@ -167,6 +231,15 @@ snapd_app_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
     case PROP_DESKTOP_FILE:
         g_value_set_string (value, app->desktop_file);
         break;
+    case PROP_SNAP:
+        g_value_set_string (value, app->snap);
+        break;
+    case PROP_ACTIVE:
+        g_value_set_boolean (value, app->active);
+        break;
+    case PROP_ENABLED:
+        g_value_set_boolean (value, app->enabled);
+        break;
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
         break;
@@ -179,8 +252,10 @@ snapd_app_finalize (GObject *object)
     SnapdApp *app = SNAPD_APP (object);
 
     g_clear_pointer (&app->name, g_free);
-    g_clear_pointer (&app->aliases, g_strfreev);
     g_clear_pointer (&app->desktop_file, g_free);
+    g_clear_pointer (&app->snap, g_free);
+
+    G_OBJECT_CLASS (snapd_app_parent_class)->finalize (object);
 }
 
 static void
@@ -220,6 +295,27 @@ snapd_app_class_init (SnapdAppClass *klass)
                                                           "App desktop file path",
                                                           NULL,
                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_SNAP,
+                                     g_param_spec_string ("snap",
+                                                          "snap",
+                                                          "Snap name",
+                                                          NULL,
+                                                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_ACTIVE,
+                                     g_param_spec_boolean ("active",
+                                                           "active",
+                                                           "TRUE if active",
+                                                           FALSE,
+                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+    g_object_class_install_property (gobject_class,
+                                     PROP_ENABLED,
+                                     g_param_spec_boolean ("enabled",
+                                                           "enabled",
+                                                           "TRUE if enabled",
+                                                           FALSE,
+                                                           G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
