@@ -55,7 +55,7 @@ G_DEFINE_TYPE (SnapdAuthData, snapd_auth_data, G_TYPE_OBJECT)
 
 /**
  * snapd_auth_data_new:
- * @macaroon: serialzied macaroon used to authorize access to snapd.
+ * @macaroon: serialized macaroon used to authorize access to snapd.
  * @discharges: (array zero-terminated=1): serialized discharges.
  *
  * Create some authorization data.
@@ -152,6 +152,8 @@ snapd_auth_data_finalize (GObject *object)
 
     g_clear_pointer (&auth_data->macaroon, g_free);
     g_clear_pointer (&auth_data->discharges, g_strfreev);
+
+    G_OBJECT_CLASS (snapd_auth_data_parent_class)->finalize (object);
 }
 
 static void
