@@ -43,6 +43,38 @@ struct _SnapdClientClass
     void (* _snapd_reserved4) (void);
 };
 
+/**
+ * SnapdChangeFilter:
+ * @SNAPD_CHANGE_FILTER_ALL: Return all changes.
+ * @SNAPD_CHANGE_FILTER_READY: Return only changes that are ready.
+ * @SNAPD_CHANGE_FILTER_IN_PROGRESS: Return only changes that are in-progress.
+ *
+ * Filter to apply to changes.
+ *
+ * Since: 1.29
+ */
+typedef enum
+{
+    SNAPD_CHANGE_FILTER_ALL,
+    SNAPD_CHANGE_FILTER_IN_PROGRESS,
+    SNAPD_CHANGE_FILTER_READY
+} SnapdChangeFilter;
+
+/**
+ * SnapdGetAppsFlags:
+ * @SNAPD_GET_APPS_FLAGS_NONE: No flags, default behaviour.
+ * @SNAPD_GET_APPS_FLAGS_SELECT_SERVICES: Select services only.
+ *
+ * Flag to change which apps are returned.
+ *
+ * Since: 1.25
+ */
+typedef enum
+{
+    SNAPD_GET_APPS_FLAGS_NONE            = 0,
+    SNAPD_GET_APPS_FLAGS_SELECT_SERVICES = 1 << 0,
+} SnapdGetAppsFlags;
+
 /**
  * SnapdFindFlags:
  * @SNAPD_FIND_FLAGS_NONE: No flags, default behaviour
@@ -156,19 +188,36 @@ void                    snapd_client_set_allow_interaction         (SnapdClient
 gboolean                snapd_client_get_allow_interaction         (SnapdClient          *client);
 
 SnapdAuthData          *snapd_client_login_sync                    (SnapdClient          *client,
-                                                                    const gchar          *username,
+                                                                    const gchar          *email,
+                                                                    const gchar          *password,
+                                                                    const gchar          *otp,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_login2_sync);
+void                    snapd_client_login_async                   (SnapdClient          *client,
+                                                                    const gchar          *email,
+                                                                    const gchar          *password,
+                                                                    const gchar          *otp,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data) G_DEPRECATED_FOR(snapd_client_login2_async);
+SnapdAuthData          *snapd_client_login_finish                  (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error) G_DEPRECATED_FOR(snapd_client_login2_finish);
+
+SnapdUserInformation   *snapd_client_login2_sync                   (SnapdClient          *client,
+                                                                    const gchar          *email,
                                                                     const gchar          *password,
                                                                     const gchar          *otp,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
-void                    snapd_client_login_async                   (SnapdClient          *client,
-                                                                    const gchar          *username,
+void                    snapd_client_login2_async                  (SnapdClient          *client,
+                                                                    const gchar          *email,
                                                                     const gchar          *password,
                                                                     const gchar          *otp,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
                                                                     gpointer              user_data);
-SnapdAuthData          *snapd_client_login_finish                  (SnapdClient          *client,
+SnapdUserInformation   *snapd_client_login2_finish                 (SnapdClient          *client,
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
@@ -176,6 +225,53 @@ void                    snapd_client_set_auth_data                 (SnapdClient
                                                                     SnapdAuthData        *auth_data);
 SnapdAuthData          *snapd_client_get_auth_data                 (SnapdClient          *client);
 
+GPtrArray              *snapd_client_get_changes_sync              (SnapdClient          *client,
+                                                                    SnapdChangeFilter     filter,
+                                                                    const gchar          *snap_name,
+                                                                    GCancellable         *cancellable,
+                                                                    GError             **error);
+
+void                    snapd_client_get_changes_async             (SnapdClient          *client,
+                                                                    SnapdChangeFilter     filter,
+                                                                    const gchar          *snap_name,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+
+GPtrArray              *snapd_client_get_changes_finish            (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
+SnapdChange            *snapd_client_get_change_sync               (SnapdClient          *client,
+                                                                    const gchar          *id,
+                                                                    GCancellable         *cancellable,
+                                                                    GError             **error);
+
+void                    snapd_client_get_change_async              (SnapdClient          *client,
+                                                                    const gchar          *id,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+
+SnapdChange            *snapd_client_get_change_finish             (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
+SnapdChange            *snapd_client_abort_change_sync             (SnapdClient          *client,
+                                                                    const gchar          *id,
+                                                                    GCancellable         *cancellable,
+                                                                    GError             **error);
+
+void                    snapd_client_abort_change_async            (SnapdClient          *client,
+                                                                    const gchar          *id,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+
+SnapdChange            *snapd_client_abort_change_finish           (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 SnapdSystemInformation *snapd_client_get_system_information_sync   (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
@@ -211,6 +307,19 @@ SnapdSnap              *snapd_client_list_one_finish               (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+GPtrArray              *snapd_client_get_apps_sync                 (SnapdClient          *client,
+                                                                    SnapdGetAppsFlags     flags,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_apps_async                (SnapdClient          *client,
+                                                                    SnapdGetAppsFlags     flags,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GPtrArray              *snapd_client_get_apps_finish               (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 SnapdIcon              *snapd_client_get_icon_sync                 (SnapdClient          *client,
                                                                     const gchar          *name,
                                                                     GCancellable         *cancellable,
@@ -521,6 +630,25 @@ gboolean                snapd_client_disable_finish                (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+gboolean                snapd_client_switch_sync                   (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    const gchar          *channel,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_switch_async                  (SnapdClient          *client,
+                                                                    const gchar          *name,
+                                                                    const gchar          *channel,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_switch_finish                 (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 gboolean                snapd_client_check_buy_sync                (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
@@ -575,6 +703,17 @@ GPtrArray              *snapd_client_create_users_finish           (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+GPtrArray              *snapd_client_get_users_sync                (SnapdClient          *client,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_get_users_async               (SnapdClient          *client,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+GPtrArray              *snapd_client_get_users_finish              (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 gchar                 **snapd_client_get_sections_sync             (SnapdClient          *client,
                                                                     GCancellable         *cancellable,
                                                                     GError              **error);
@@ -597,13 +736,70 @@ GPtrArray              *snapd_client_get_aliases_finish            (SnapdClient
                                                                     GAsyncResult         *result,
                                                                     GError              **error);
 
+gboolean                snapd_client_alias_sync                    (SnapdClient          *client,
+                                                                    const gchar          *snap,
+                                                                    const gchar          *app,
+                                                                    const gchar          *alias,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_alias_async                   (SnapdClient          *client,
+                                                                    const gchar          *snap,
+                                                                    const gchar          *app,
+                                                                    const gchar          *alias,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_alias_finish                  (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
+gboolean                snapd_client_unalias_sync                  (SnapdClient          *client,
+                                                                    const gchar          *snap,
+                                                                    const gchar          *alias,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_unalias_async                 (SnapdClient          *client,
+                                                                    const gchar          *snap,
+                                                                    const gchar          *alias,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_unalias_finish                (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
+gboolean                snapd_client_prefer_sync                   (SnapdClient          *client,
+                                                                    const gchar          *snap,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GError              **error);
+void                    snapd_client_prefer_async                  (SnapdClient          *client,
+                                                                    const gchar          *snap,
+                                                                    SnapdProgressCallback progress_callback,
+                                                                    gpointer              progress_callback_data,
+                                                                    GCancellable         *cancellable,
+                                                                    GAsyncReadyCallback   callback,
+                                                                    gpointer              user_data);
+gboolean                snapd_client_prefer_finish                 (SnapdClient          *client,
+                                                                    GAsyncResult         *result,
+                                                                    GError              **error);
+
 gboolean                snapd_client_enable_aliases_sync           (SnapdClient          *client,
                                                                     const gchar          *snap,
                                                                     gchar               **aliases,
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED;
 void                    snapd_client_enable_aliases_async          (SnapdClient          *client,
                                                                     const gchar          *snap,
                                                                     gchar               **aliases,
@@ -611,10 +807,10 @@ void                    snapd_client_enable_aliases_async          (SnapdClient
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED;
 gboolean                snapd_client_enable_aliases_finish         (SnapdClient          *client,
                                                                     GAsyncResult         *result,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED;
 
 gboolean                snapd_client_disable_aliases_sync          (SnapdClient          *client,
                                                                     const gchar          *snap,
@@ -622,7 +818,7 @@ gboolean                snapd_client_disable_aliases_sync          (SnapdClient
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED;
 void                    snapd_client_disable_aliases_async         (SnapdClient          *client,
                                                                     const gchar          *snap,
                                                                     gchar               **aliases,
@@ -630,10 +826,10 @@ void                    snapd_client_disable_aliases_async         (SnapdClient
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED;
 gboolean                snapd_client_disable_aliases_finish        (SnapdClient          *client,
                                                                     GAsyncResult         *result,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED;
 
 gboolean                snapd_client_reset_aliases_sync            (SnapdClient          *client,
                                                                     const gchar          *snap,
@@ -641,7 +837,7 @@ gboolean                snapd_client_reset_aliases_sync            (SnapdClient
                                                                     SnapdProgressCallback progress_callback,
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED;
 void                    snapd_client_reset_aliases_async           (SnapdClient          *client,
                                                                     const gchar          *snap,
                                                                     gchar               **aliases,
@@ -649,10 +845,10 @@ void                    snapd_client_reset_aliases_async           (SnapdClient
                                                                     gpointer              progress_callback_data,
                                                                     GCancellable         *cancellable,
                                                                     GAsyncReadyCallback   callback,
-                                                                    gpointer              user_data);
+                                                                    gpointer              user_data) G_DEPRECATED;
 gboolean                snapd_client_reset_aliases_finish          (SnapdClient          *client,
                                                                     GAsyncResult         *result,
-                                                                    GError              **error);
+                                                                    GError              **error) G_DEPRECATED;
 
 gboolean                snapd_client_run_snapctl_sync              (SnapdClient          *client,
                                                                     const gchar          *context_id,
