@@ -51,6 +51,10 @@ G_BEGIN_DECLS
  *     mode.
  * @SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM: a classic system is required to install
  *    this snap.
+ * @SNAPD_ERROR_BAD_QUERY: a bad query was provided.
+ * @SNAPD_ERROR_NETWORK_TIMEOUT: A timeout occurred during the request.
+ * @SNAPD_ERROR_NOT_FOUND: the requested snap couldn't be found.
+ * @SNAPD_ERROR_NOT_IN_STORE: the requested snap is not in the store.
  *
  * Error codes returned by snapd operations.
  *
@@ -78,7 +82,11 @@ typedef enum
     SNAPD_ERROR_PASSWORD_POLICY_ERROR,
     SNAPD_ERROR_NEEDS_DEVMODE,
     SNAPD_ERROR_NEEDS_CLASSIC,
-    SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM
+    SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM,
+    SNAPD_ERROR_BAD_QUERY,
+    SNAPD_ERROR_NETWORK_TIMEOUT,
+    SNAPD_ERROR_NOT_FOUND,
+    SNAPD_ERROR_NOT_IN_STORE
 } SnapdError;
 
 /**
