@@ -241,6 +241,16 @@ parse_error_response (JsonObject *root, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_NOT_INSTALLED,
                              message);
+    else if (g_strcmp0 (kind, "snap-not-found") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_NOT_FOUND,
+                             message);
+    else if (g_strcmp0 (kind, "snap-local") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_NOT_IN_STORE,
+                             message);
     else if (g_strcmp0 (kind, "snap-no-update-available") == 0)
         g_set_error_literal (error,
                              SNAPD_ERROR,
@@ -266,6 +276,16 @@ parse_error_response (JsonObject *root, GError **error)
                              SNAPD_ERROR,
                              SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM,
                              message);
+    else if (g_strcmp0 (kind, "bad-query") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_BAD_QUERY,
+                             message);
+    else if (g_strcmp0 (kind, "network-timeout") == 0)
+        g_set_error_literal (error,
+                             SNAPD_ERROR,
+                             SNAPD_ERROR_NETWORK_TIMEOUT,
+                             message);
     else {
         switch (status_code) {
         case SOUP_STATUS_BAD_REQUEST:
