@@ -152,7 +152,7 @@ snapd_task_get_status (SnapdTask *task)
  *
  * Get if this task is completed.
  *
- * Depcrecated: 1.5: Use snapd_change_get_ready() instead.
+ * Deprecated: 1.5: Use snapd_change_get_ready() instead.
  *
  * Returns: %TRUE if this task is complete.
  *
@@ -378,6 +378,8 @@ snapd_task_finalize (GObject *object)
     g_clear_pointer (&task->progress_label, g_free);
     g_clear_pointer (&task->spawn_time, g_date_time_unref);
     g_clear_pointer (&task->ready_time, g_date_time_unref);
+
+    G_OBJECT_CLASS (snapd_task_parent_class)->finalize (object);
 }
 
 static void
