@@ -738,8 +738,8 @@ private:
     Q_DECLARE_PRIVATE(QSnapdRunSnapCtlRequest)
 };
 
-Q_INVOKABLE QSnapdLoginRequest *login (const QString& email, const QString& password);
-Q_INVOKABLE QSnapdLoginRequest *login (const QString& email, const QString& password, const QString& otp);
+Q_INVOKABLE Q_DECL_DEPRECATED QSnapdLoginRequest *login (const QString& email, const QString& password);
+Q_INVOKABLE Q_DECL_DEPRECATED QSnapdLoginRequest *login (const QString& email, const QString& password, const QString& otp);
 
 class QSnapdClientPrivate;
 class Q_DECL_EXPORT QSnapdClient : public QObject
@@ -816,8 +816,10 @@ public:
     Q_INVOKABLE QSnapdGetInterfacesRequest *getInterfaces ();
     Q_INVOKABLE QSnapdConnectInterfaceRequest *connectInterface (const QString &plug_snap, const QString &plug_name, const QString &slot_snap, const QString &slot_name);
     Q_INVOKABLE QSnapdDisconnectInterfaceRequest *disconnectInterface (const QString &plug_snap, const QString &plug_name, const QString &slot_snap, const QString &slot_name);
+    Q_INVOKABLE QSnapdFindRequest *find (const QString &query);
     Q_INVOKABLE QSnapdFindRequest *find (FindFlags flags);
     Q_INVOKABLE QSnapdFindRequest *find (FindFlags flags, const QString &query);
+    Q_INVOKABLE QSnapdFindRequest *findSection (const QString &section, const QString &query);
     Q_INVOKABLE QSnapdFindRequest *findSection (FindFlags flags, const QString &section, const QString &query);
     Q_INVOKABLE QSnapdFindRefreshableRequest *findRefreshable ();
     Q_INVOKABLE QSnapdInstallRequest *install (const QString &name);
