@@ -50,7 +50,11 @@ public:
         NeedsDevmode,
         NeedsClassic,
         NeedsClassicSystem,
-        Cancelled
+        Cancelled,
+        BadQuery,
+        NetworkTimeout,
+        NotFound,
+        NotInStore
     };
     Q_ENUM(QSnapdError)
 
