@@ -18,13 +18,14 @@ QString QSnapdApp::name () const
     return snapd_app_get_name (SNAPD_APP (wrapped_object));
 }
 
+bool QSnapdApp::active () const
+{
+    return snapd_app_get_active (SNAPD_APP (wrapped_object));
+}
+
 QStringList QSnapdApp::aliases () const
 {
-    gchar **aliases = snapd_app_get_aliases (SNAPD_APP (wrapped_object));
-    QStringList result;
-    for (int i = 0; aliases[i] != NULL; i++)
-        result.append (aliases[i]);
-    return result;
+    return QStringList ();
 }
 
 QSnapdEnums::DaemonType QSnapdApp::daemonType () const
@@ -53,3 +54,13 @@ QString QSnapdApp::desktopFile () const
 {
     return snapd_app_get_desktop_file (SNAPD_APP (wrapped_object));
 }
+
+bool QSnapdApp::enabled () const
+{
+    return snapd_app_get_enabled (SNAPD_APP (wrapped_object));
+}
+
+QString QSnapdApp::snap () const
+{
+    return snapd_app_get_snap (SNAPD_APP (wrapped_object));
+}
