@@ -24,19 +24,65 @@ class QSnapdConnectRequestPrivate
 class QSnapdLoginRequestPrivate
 {
 public:
-    QSnapdLoginRequestPrivate (const QString& username, const QString& password, const QString& otp) :
-        username(username), password(password), otp(otp) {}
+    QSnapdLoginRequestPrivate (const QString& email, const QString& password, const QString& otp) :
+        email(email), password(password), otp(otp) {}
     ~QSnapdLoginRequestPrivate ()
     {
+        if (user_information != NULL)
+            g_object_unref (user_information);
         if (auth_data != NULL)
             g_object_unref (auth_data);
     }
-    QString username;
+    QString email;
     QString password;
     QString otp;
+    SnapdUserInformation *user_information = NULL;
     SnapdAuthData *auth_data = NULL;
 };
 
+class QSnapdGetChangesRequestPrivate
+{
+public:
+    QSnapdGetChangesRequestPrivate (int filter, const QString& snapName) :
+        filter(filter), snapName(snapName) {}
+    ~QSnapdGetChangesRequestPrivate ()
+    {
+        if (changes != NULL)
+            g_ptr_array_unref (changes);
+    }
+    int filter;
+    QString snapName;
+    GPtrArray *changes = NULL;
+};
+
+class QSnapdGetChangeRequestPrivate
+{
+public:
+    QSnapdGetChangeRequestPrivate (const QString& id) :
+        id(id) {}
+    ~QSnapdGetChangeRequestPrivate ()
+    {
+        if (change != NULL)
+            g_object_unref (change);
+    }
+    QString id;
+    SnapdChange *change = NULL;
+};
+
+class QSnapdAbortChangeRequestPrivate
+{
+public:
+    QSnapdAbortChangeRequestPrivate (const QString& id) :
+        id(id) {}
+    ~QSnapdAbortChangeRequestPrivate ()
+    {
+        if (change != NULL)
+            g_object_unref (change);
+    }
+    QString id;
+    SnapdChange *change = NULL;
+};
+
 class QSnapdGetSystemInformationRequestPrivate
 {
 public:
@@ -73,6 +119,20 @@ public:
     SnapdSnap *snap = NULL;
 };
 
+class QSnapdGetAppsRequestPrivate
+{
+public:
+    QSnapdGetAppsRequestPrivate (int flags) :
+        flags(flags) {}
+    ~QSnapdGetAppsRequestPrivate ()
+    {
+        if (apps != NULL)
+            g_ptr_array_unref (apps);
+    }
+    int flags;
+    GPtrArray *apps = NULL;
+};
+
 class QSnapdGetIconRequestPrivate
 {
 public:
@@ -255,6 +315,15 @@ public:
     QString name;
 };
 
+class QSnapdSwitchChannelRequestPrivate
+{
+public:
+    QSnapdSwitchChannelRequestPrivate (const QString& name, const QString& channel) :
+        name(name), channel(channel) {}
+    QString name;
+    QString channel;
+};
+
 class QSnapdCheckBuyRequestPrivate
 {
 public:
@@ -271,6 +340,43 @@ public:
     QString currency;
 };
 
+class QSnapdCreateUserRequestPrivate
+{
+public:
+    QSnapdCreateUserRequestPrivate (const QString& email, int flags) :
+      email(email), flags(flags) {}
+    ~QSnapdCreateUserRequestPrivate ()
+    {
+        if (info != NULL)
+            g_object_unref (info);
+    }
+    QString email;
+    int flags;
+    SnapdUserInformation *info = NULL;
+};
+
+class QSnapdCreateUsersRequestPrivate
+{
+public:
+    ~QSnapdCreateUsersRequestPrivate ()
+    {
+        if (info != NULL)
+            g_ptr_array_unref (info);
+    }
+    GPtrArray *info = NULL;
+};
+
+class QSnapdGetUsersRequestPrivate
+{
+public:
+    ~QSnapdGetUsersRequestPrivate ()
+    {
+        if (info != NULL)
+            g_ptr_array_unref (info);
+    }
+    GPtrArray *info = NULL;
+};
+
 class QSnapdGetSectionsRequestPrivate
 {
 public:
@@ -293,6 +399,35 @@ public:
     GPtrArray *aliases = NULL;
 };
 
+class QSnapdAliasRequestPrivate
+{
+public:
+    QSnapdAliasRequestPrivate (const QString &snap, const QString &app, const QString &alias) :
+        snap (snap), app (app), alias (alias) {}
+    QString snap;
+    QString app;
+    QString alias;
+};
+
+class QSnapdUnaliasRequestPrivate
+{
+public:
+    QSnapdUnaliasRequestPrivate (const QString &snap, const QString &alias) :
+        snap (snap), alias (alias) {}
+    QString snap;
+    QString alias;
+};
+
+class QSnapdPreferRequestPrivate
+{
+public:
+    QSnapdPreferRequestPrivate (const QString &snap) :
+        snap (snap) {}
+    QString snap;
+    QString app;
+    QString alias;
+};
+
 class QSnapdEnableAliasesRequestPrivate
 {
 public:
