@@ -135,6 +135,18 @@ void QSnapdRequest::finish (void *error)
             case SNAPD_ERROR_NEEDS_CLASSIC_SYSTEM:
                 d->error = QSnapdRequest::QSnapdError::NeedsClassicSystem;
                 break;
+            case SNAPD_ERROR_BAD_QUERY:
+                d->error = QSnapdRequest::QSnapdError::BadQuery;
+                break;
+            case SNAPD_ERROR_NETWORK_TIMEOUT:
+                d->error = QSnapdRequest::QSnapdError::NetworkTimeout;
+                break;
+            case SNAPD_ERROR_NOT_FOUND:
+                d->error = QSnapdRequest::QSnapdError::NotFound;
+                break;
+            case SNAPD_ERROR_NOT_IN_STORE:
+                d->error = QSnapdRequest::QSnapdError::NotInStore;
+                break;
             default:
                 /* This indicates we should add a new entry here... */
                 d->error = QSnapdRequest::QSnapdError::UnknownError;
